
function demo_RQ_01(example)

warning off;

if nargin < 1, example=1; end
n=5;

% ................  DETERMINE EXPERIMENT ................
[x0,x1,mult0,mult1]=polesData(example);

% ................  DETERMINE WEIGHT FUNCTION ................
w=@(t) 1./((t-x0).^mult0 .*(t-x1).^mult1);

% ................ RFEJER PREPARATION  ................
if (mult0+mult1) > n, nF=0; else, nF=n-(mult0+mult1); end
denmat=[x0 mult0; x1 mult1];
sgl=encodeRFejer(nF,denmat);
[xRF,ErrRF,RelRF,yRF]=rfejer(sgl);
xF=(xRF(1,:))'; wF=(xRF(2,:))';

% ............... GAU.LEG. PREPARATION  ...............

[X,W]=legpts(10000); xL=X; wL=W';

% ................ NUMER. EXPERIMENTS  ................
I=[];

for k=0:n

    f=@(x) cos(k*acos(x)).*w(x);

    % METHOD I: CHEBFUN
    F=chebfun(f,'splitting','on');
    I1=sum(F);

    % METHOD II: INTEGRAL
    tol=10^(-15);
    I2=integral(f,-1,1,'AbsTol',tol,'RelTol',tol);

    % METHOD III: RFEJER
    fxF=feval(f,xF);
    I3=wF'*fxF;

    % METHOD IV: GAUSS-LEGENDRE
    fxL=feval(f,xL);
    I4=wL'*fxL;

    % METHOD V: SYMBOLIC
    syms s; syms g;
    g=cos(k*acos(s))/((s-x0)^mult0 *(s-x1).^mult1);
    I5=vpa(int(g,-1,1));


    % STATS:
    fprintf('\n \t ........................................................');
    fprintf('\n \t DEGREE : %6.0f',k);
    fprintf('\n \t CHEBFUN: %1.20e %1.1e',I1(end),abs( (I1(end)-I5(end))/I5(end)));
    fprintf('\n \t INTEGRA: %1.20e %1.1e',I2(end),abs( (I2(end)-I5(end))/I5(end)));
    fprintf('\n \t RFEJER : %1.20e %1.1e',I3(end),abs( (I3(end)-I5(end))/I5(end)));
    fprintf('\n \t GAULEG.: %1.20e %1.1e',I4(end),abs( (I4(end)-I5(end))/I5(end)));
    fprintf('\n \t SYMBOL.: %1.20e',I5(end));
end

fprintf('\n \n');



function [x0,x1,mult0,mult1]=polesData(example)

switch example
     case 0 
         % * POLES NOT TOO CLOSE BUT WITH HIGH MULTIPLICITY.
         % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
         x0=1.3; x1=-1.3; mult0=20; mult1=mult0;
    case 1 
        % * POLES NOT TOO FAR BUT WITH MID MULTIPLICITY.
        % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
        x0=1.1; x1=-1.1; mult0=6; mult1=mult0;
    case 2 
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0".
        % ** MODEST LOSS FOR ALL THE CODES, WITH THE EXCEPTION OF 
        % GAUSS-LEGENDRE WITH 10000 POINTS THAT HAS TROUBLES WITH EVEN
        % DEGREES.
        x0=i*10^(-4); x1=conj(x0); mult0=1; mult1=mult0;
    case 3 
        % * COMPLEX POLE CLOSE TO EXTREMA, MILD MULTIPLICITY.
        % ** MANY PROBLEMS HERE, WITH DOUBTS ON SYMBOLIC CALCULUS.
        % ALL THE RESULTS ARE SIMILAR BUT "rfejer".
        x0=1.1+i*10^(-4); x1=conj(x0); mult0=8; mult1=mult0;
    case 4 
        % * COMPLEX POLE CLOSE TO EXTREMA, LOW/MILD MULTIPLICITY.
        % ** MOMENTS MAY BE LARGE (10^27). PROBLEMS WITH CHEBFUN AND
        % GAUSS-LEGENDRE FOR ALL POSITIVE INTEGERS. PROBLEMS FOR OTHER
        % METHODS FOR ODD DEGREES.
        x0=i*10^(-4); x1=conj(x0); mult0=4; mult1=mult0;
    case 5 
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0". LOW MULTIPLICITY.
        %   SOME RATHER LARGE MOMENTS: 
        % ** SOME LOSS IN ODD DEGREES, BAD GAUSS-LEGENDRE WITH 10000 POINTS.
        x0=i*10^(-4); x1=conj(x0); mult0=2; mult1=mult0;
    case 6 
        % * ASYMMETRIC LOCATION OF REAL POLES CLOSE TO EXTREMA.
        %   ASYMMETRICAL MULTIPLICITIES.
        % ** LARGE MOMENTS BUT GOOD RELATIVE ERRORS.
        x0=1.00001; x1=-1.01; mult0=4; mult1=20;
    case 7 
        % * COMPLEX CONJUGATE POLES, NOT TOO CLOSE TO "0". LOW MULTIPLICITY.
        % ** SOME WARNINGS BUT GOOD RESULTS.
        x0=0.5*i; x1=conj(x0); mult0=4; mult1=mult0;
    otherwise 
         % * SYMMETRIC LOCATION OF REAL POLES NOT TOO CLOSE TO EXTREMA.
        %   ASYMMETRICAL HIGH MULTIPLICITIES.
        % ** GOOD RESULTS.
        x0=2; x1=-2; mult0=10; mult1=20;
end
