
function demo_RQ_04(example)

warning off;

if nargin < 1, example=1; end
n=5;

% ................  DETERMINE EXPERIMENT ................
[X,M]=polesData(example);

% ................  DETERMINE WEIGHT FUNCTION ................
if length(X) == 3
w=@(t) 1./((t-X(1)).^M(1) .*(t-X(2)).^M(2)).*(t-X(3)).^M(3));
else
end

% ................ RFEJER PREPARATION  ................
if (M(1)+M(2)) > n, nF=0; else, nF=n-(M(1)+M(2)); end
denmat=[X(1) M(1); X(2) M(2)];
sgl=encodeRFejer(nF,denmat);
[xRF,ErrRF,RelRF,yRF]=rfejer(sgl);
xF=(xRF(1,:))'; wF=(xRF(2,:))';

% ............... GAU.LEG. PREPARATION  ...............

[X,W]=legpts(10000); xL=X; wL=W';

% ................ NUMER. EXPERIMENTS  ................
I=[];

for k=0:n

    f=@(x) cos(k*acos(x)).*w(x);

    % METHOD I: CHEBFUN
    F=chebfun(f,'splitting','on');
    I1=sum(F);

    % METHOD II: INTEGRAL
    tol=10^(-15);
    I2=integral(f,-1,1,'AbsTol',tol,'RelTol',tol);

    % METHOD III: RFEJER
    fxF=feval(f,xF);
    I3=wF'*fxF;

    % METHOD IV: GAUSS-LEGENDRE
    fxL=feval(f,xL);
    I4=wL'*fxL;

    % METHOD V: SYMBOLIC
    syms s; syms g;
    g=cos(k*acos(s))/((s-X(1))^M(1) *(s-X(2)).^M(2));
    I5=vpa(int(g,-1,1));


    % STATS:
    fprintf('\n \t ........................................................');
    fprintf('\n \t DEGREE : %6.0f',k);
    fprintf('\n \t CHEBFUN: %1.20e %1.1e',I1(end),abs( (I1(end)-I5(end))/I5(end)));
    fprintf('\n \t INTEGRA: %1.20e %1.1e',I2(end),abs( (I2(end)-I5(end))/I5(end)));
    fprintf('\n \t RFEJER : %1.20e %1.1e',I3(end),abs( (I3(end)-I5(end))/I5(end)));
    fprintf('\n \t GAULEG.: %1.20e %1.1e',I4(end),abs( (I4(end)-I5(end))/I5(end)));
    fprintf('\n \t SYMBOL.: %1.20e',I5(end));
end

fprintf('\n \n');



function [X,M]=polesData(example)

switch example
     case 0 
         % * POLES NOT TOO CLOSE BUT WITH HIGH MULTIPLICITY.
         % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
         X(1)=1.3; X(2)=-1.3; M(1)=20; M(2)=M(1);
    case 1 
        % * POLES NOT TOO FAR BUT WITH MID MULTIPLICITY.
        % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
        X(1)=1.1; X(2)=-1.1; M(1)=6; M(2)=M(1);
    case 2 
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0".
        % ** MODEST LOSS FOR ALL THE CODES, WITH THE EXCEPTION OF 
        % GAUSS-LEGENDRE WITH 10000 POINTS THAT HAS TROUBLES WITH EVEN
        % DEGREES.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=1; M(2)=M(1);
    case 3 
        % * COMPLEX POLE CLOSE TO EXTREMA, MILD MULTIPLICITY.
        % ** MANY PROBLEMS HERE, WITH DOUBTS ON SYMBOLIC CALCULUS.
        % ALL THE RESULTS ARE SIMILAR BUT "rfejer".
        X(1)=1.1+i*10^(-4); X(2)=conj(X(1)); M(1)=8; M(2)=M(1);
    case 4 
        % * COMPLEX POLE CLOSE TO EXTREMA, LOW/MILD MULTIPLICITY.
        % ** MOMENTS MAY BE LARGE (10^27). PROBLEMS WITH CHEBFUN AND
        % GAUSS-LEGENDRE FOR ALL POSITIVE INTEGERS. PROBLEMS FOR OTHER
        % METHODS FOR ODD DEGREES.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=4; M(2)=M(1);
    case 5 
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0". LOW MULTIPLICITY.
        %   SOME RATHER LARGE MOMENTS: 
        % ** SOME LOSS IN ODD DEGREES, BAD GAUSS-LEGENDRE WITH 10000 POINTS.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=2; M(2)=M(1);
    case 6 
        % * ASYMMETRIC LOCATION OF REAL POLES CLOSE TO EXTREMA.
        %   ASYMMETRICAL MULTIPLICITIES.
        % ** LARGE MOMENTS BUT GOOD RELATIVE ERRORS.
        X(1)=1.00001; X(2)=-1.01; M(1)=4; M(2)=20;
    case 7 
        % * COMPLEX CONJUGATE POLES, NOT TOO CLOSE TO "0". LOW MULTIPLICITY.
        % ** SOME WARNINGS BUT GOOD RESULTS.
        X(1)=0.5*i; X(2)=conj(X(1)); M(1)=4; M(2)=M(1);
    otherwise 
         % * SYMMETRIC LOCATION OF REAL POLES NOT TOO CLOSE TO EXTREMA.
        %   ASYMMETRICAL HIGH MULTIPLICITIES.
        % ** GOOD RESULTS.
        X(1)=2; X(2)=-2; M(1)=10; M(2)=20;
end
