
function demo_rfejer_01

% ................  DETERMINE EXPERIMENT ................
X(1)=2; M(1)=6;

w=@(t) 1./(t-X(1)).^M(1);
KK=8; f=@(x) cos((KK+M(1))*acos(x)).*w(x);

% integral
I=integral(f,-1,1,'AbsTol',10^(-14),'RelTol',10^(-14));
fprintf('\n \t * I : %1.20e \n',I)

% chebfun
F=chebfun(f);
IC=sum(F);
fprintf('\n \t * IC: %1.20e',IC)
fprintf('\n \t RE C: %1.3e \n',abs(IC-I)/abs(I))

% ............... GAU.LEG. PREPARATION  ...............
[XL,WL]=legpts(10000); xL=XL; wL=WL';
fxL=feval(f,xL);
IGL=wL'*fxL;
fprintf('\n \t * IG: %1.20e',IGL)
fprintf('\n \t RE G: %1.3e \n',abs(IGL-I)/abs(I))

% fejer
for nF=1:KK+M(1)+5
    denmat=[X(1) M(1)];
    sgl=encodeRFejer(nF,denmat);
    [xRF,ErrRF,RelRF,yRF]=rfejer(sgl);
    xF=(xRF(1,:))'; wF=(xRF(2,:))';
    fxF=feval(f,xF);
    IF=wF'*fxF;
    fprintf('\n \t .......... %3.0f ..........  ',nF)
    fprintf('\n \t IF: %1.20e',IF)
    fprintf('\n \t AE F: %1.3e',abs(IF-I))
    fprintf('\n \t RE F: %1.3e',abs(IF-I)/abs(I))
end
fprintf('\n \n \f DEGREE: %4.0f',KK)


fprintf('\n \n')


function [X,M]=polesData(example)

switch example

    case -1
        % * POLES NOT TOO CLOSE BUT WITH HIGH MULTIPLICITY.
        % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
        X(1)=1.5; M(1)=6;

    case 0
        % * POLES NOT TOO CLOSE BUT WITH HIGH MULTIPLICITY.
        % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
        X(1)=1.3; X(2)=-1.3; M(1)=20; M(2)=M(1);
    case 1
        % * POLES NOT TOO FAR BUT WITH MID MULTIPLICITY.
        % ** ALL THE CODES WORK FINE, WITH WARNINGS FROM ADAPTIVE CODES.
        X(1)=1.1; X(2)=-1.1; M(1)=6; M(2)=M(1);
    case 2
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0".
        % ** MODEST LOSS FOR ALL THE CODES, WITH THE EXCEPTION OF
        % GAUSS-LEGENDRE WITH 10000 POINTS THAT HAS TROUBLES WITH EVEN
        % DEGREES.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=1; M(2)=M(1);
    case 3
        % * COMPLEX POLE CLOSE TO EXTREMA, MILD MULTIPLICITY.
        % ** MANY PROBLEMS HERE, WITH DOUBTS ON SYMBOLIC CALCULUS.
        % ALL THE RESULTS ARE SIMILAR BUT "rfejer".
        X(1)=1.1+i*10^(-4); X(2)=conj(X(1)); M(1)=8; M(2)=M(1);
    case 4
        % * COMPLEX POLE CLOSE TO EXTREMA, LOW/MILD MULTIPLICITY.
        % ** MOMENTS MAY BE LARGE (10^27). PROBLEMS WITH CHEBFUN AND
        % GAUSS-LEGENDRE FOR ALL POSITIVE INTEGERS. PROBLEMS FOR OTHER
        % METHODS FOR ODD DEGREES.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=4; M(2)=M(1);
    case 5
        % * COMPLEX CONJUGATE POLES, CLOSE TO "0". LOW MULTIPLICITY.
        %   SOME RATHER LARGE MOMENTS:
        % ** SOME LOSS IN ODD DEGREES, BAD GAUSS-LEGENDRE WITH 10000 POINTS.
        X(1)=i*10^(-4); X(2)=conj(X(1)); M(1)=2; M(2)=M(1);
    case 6
        % * ASYMMETRIC LOCATION OF REAL POLES CLOSE TO EXTREMA.
        %   ASYMMETRICAL MULTIPLICITIES.
        % ** LARGE MOMENTS BUT GOOD RELATIVE ERRORS.
        X(1)=1.00001; X(2)=-1.01; M(1)=4; M(2)=20;
    case 7
        % * COMPLEX CONJUGATE POLES, NOT TOO CLOSE TO "0". LOW MULTIPLICITY.
        % ** SOME WARNINGS BUT GOOD RESULTS.
        X(1)=0.5*i; X(2)=conj(X(1)); M(1)=4; M(2)=M(1);
    otherwise
        % * SYMMETRIC LOCATION OF REAL POLES NOT TOO CLOSE TO EXTREMA.
        %   ASYMMETRICAL HIGH MULTIPLICITIES.
        % ** GOOD RESULTS.
        X(1)=2; X(2)=-2; M(1)=10; M(2)=20;
end
